==> c8y_client-0.0.2.tar.gz: example/c8y_client_example.dart <==
import 'package:c8y_client/c8y_client.dart';
import 'package:c8y_client/src/core/authentication/cumulocity_credentials.dart';
import 'package:c8y_client/src/core/model/device_capabilities/c8y_position.dart';
import 'package:c8y_client/src/sdk/client/client.dart';

void main() async {

  var client = Client.withPageSize('https://tenant.service-provider.com',
      CumulocityCredentials('usrname', 'password'), 2000);


  var currentUser = await client.user().currentUser();
  print(currentUser.userName);

  var inventoryApi = client.inventory();
  var mo = await inventoryApi.get(ID('10407719'));
  print(mo.name);
  print(mo.fragments['Numero_de_Satelites']);


  var iterator = await inventoryApi.stream({'fragmentType': 'c8y_Position'});
  var counter = 0;
  while (await iterator.moveNext()) {
    var position = C8YPosition.fromJson(
        iterator.current.fragments['c8y_Position'] as Map<String, Object>);
//    print(position.lat);
    counter++;
  }
  print('total devices stream : ' + counter.toString());

  var devices = await inventoryApi.listAll({'fragmentType': 'c8y_Position'});
  print('total devices listAll : ' + devices.length.toString());

  var devicesByLimit =
      await inventoryApi.listByLimit({'fragmentType': 'c8y_Position'}, 40);
  print('total devices list with limit : ' + devicesByLimit.length.toString());

  var alarmApi = client.alarm();
  counter = 0;
  var alarmsIterator = await alarmApi.stream({});
  while (await alarmsIterator.moveNext()) {
//    print(alarmsIterator.current.text);
    counter++;
  }
  print('total alarms stream : ' + counter.toString());


  var alarms = await alarmApi.listAll({});
  print('total alarms listall : ' + alarms.length.toString());

  var alarmsByLimit = await alarmApi.listByLimit({}, 40);
  print('total alarms list with limit : ' + alarmsByLimit.length.toString());
}

==> c8y_client-0.0.3.tar.gz: example/c8y_client_example.dart <==
import 'package:c8y_client/c8y_client.dart';
import 'package:c8y_client/src/core/authentication/cumulocity_credentials.dart';
import 'package:c8y_client/src/core/model/device_capabilities/c8y_position.dart';
import 'package:c8y_client/src/sdk/client/client.dart';

void main() async {

  var client = Client.withPageSize('https://tenant.service-provider.com',
      CumulocityCredentials('usrname', 'password'), 2000);


  var currentUser = await client.user().currentUser();
  print(currentUser.userName);

  var inventoryApi = client.inventory();
  var mo = await inventoryApi.get(ID('10407719'));
  print(mo.name);
  print(mo.fragments['Numero_de_Satelites']);


  var iterator = await inventoryApi.stream({'fragmentType': 'c8y_Position'});
  var counter = 0;
  while (await iterator.moveNext()) {
    var position = C8YPosition.fromJson(
        iterator.current.fragments['c8y_Position'] as Map<String, Object>);
    print(position.lat);
    counter++;
  }
  print('total devices stream : ' + counter.toString());

  var devices = await inventoryApi.listAll({'fragmentType': 'c8y_Position'});
  print('total devices listAll : ' + devices.length.toString());

  var devicesByLimit =
      await inventoryApi.listByLimit({'fragmentType': 'c8y_Position'}, 40);
  print('total devices list with limit : ' + devicesByLimit.length.toString());

  var alarmApi = client.alarm();
  counter = 0;
  var alarmsIterator = await alarmApi.stream({});
  while (await alarmsIterator.moveNext()) {
  print(alarmsIterator.current.text);
    counter++;
  }
  print('total alarms stream : ' + counter.toString());


  var alarms = await alarmApi.listAll({});
  print('total alarms listall : ' + alarms.length.toString());

  var alarmsByLimit = await alarmApi.listByLimit({}, 40);
  print('total alarms list with limit : ' + alarmsByLimit.length.toString());
}
